==> Joomla_3.2.2_in_Japanese.zip: Joomla_3.2.2_in_Japanese/media/editors/tinymce/langs/sk.js <==
tinymce.addI18n('sk',{
"Cut": "Vystrihn\u00fa\u0165",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "V\u00e1\u0161 prehliada\u010d nepodporuje priamy pr\u00edstup do schr\u00e1nky. Pou\u017eite kl\u00e1vesov\u00e9 skratky Ctrl+X\/C\/V.",
"Paste": "Vlo\u017ei\u0165",
"Close": "Zatvori\u0165",
"Align right": "Zarovna\u0165 vpravo",
"New document": "Nov\u00fd dokument",
"Numbered list": "\u010c\u00edslovan\u00fd zoznam",
"Increase indent": "Zv\u00e4\u010d\u0161i\u0165 odsadenie",
"Formats": "Form\u00e1ty",
"Select all": "Ozna\u010di\u0165 v\u0161etko",
"Undo": "Vr\u00e1ti\u0165",
"Strikethrough": "Pre\u010diarknut\u00e9",
"Bullet list": "Odr\u00e1\u017eky",
"Superscript": "Horn\u00fd index",
"Clear formatting": "Vymaza\u0165 form\u00e1tovanie",
"Subscript": "Spodn\u00fd index",
"Redo": "Znova",
"Ok": "Ok",
"Bold": "Tu\u010dn\u00e9",
"Italic": "Kurz\u00edva",
"Align center": "Zarovna\u0165 na stred",
"Decrease indent": "Zmen\u0161i\u0165 odsadenie",
"Underline": "Pod\u010diarknut\u00e9",
"Cancel": "Zru\u0161i\u0165",
"Justify": "Zarovna\u0165",
"Copy": "Kop\u00edrova\u0165",
"Align left": "Zarovna\u0165 v\u013eavo",
"Visual aids": "Vizu\u00e1lne pom\u00f4cky",
"Lower Greek": "Mal\u00e9 gr\u00e9cke p\u00edsmen\u00e1",
"Square": "\u0160tvorec",
"Default": "V\u00fdchodzie",
"Lower Alpha": "Mal\u00e9 p\u00edsmen\u00e1",
"Circle": "Kruh",
"Disc": "Disk",
"Upper Alpha": "Ve\u013ek\u00e9 p\u00edsmen\u00e1",
"Upper Roman": "Ve\u013ek\u00e9 r\u00edmske \u010d\u00edslice",
"Lower Roman": "Mal\u00e9 r\u00edmske \u010d\u00edslice",
"Name": "N\u00e1zov",
"Anchor": "Odkaz",
"You have unsaved changes are you sure you want to navigate away?": "M\u00e1te neulo\u017een\u00e9 zmeny, naozaj chcete opusti\u0165 str\u00e1nku?",
"Restore last draft": "Obnovi\u0165 posledn\u00fd koncept",
"Special character": "\u0160peci\u00e1lny znak",
"Source code": "Zdrojov\u00fd k\u00f3d",
"Right to left": "Sprava do\u013eava",
"Left to right": "Z\u013eava doprava",
"Emoticons": "Smajl\u00edci",
"Robots": "Preh\u013ead\u00e1vacie roboty",
"Document properties": "Vlastnosti dokumentu",
"Title": "Nadpis",
"Keywords": "K\u013e\u00fa\u010dov\u00e9 slov\u00e1",
"Encoding": "K\u00f3dovanie",
"Description": "Popis",
"Author": "Autor",
"Fullscreen": "Na cel\u00fa obrazovku",
"Horizontal line": "Horizont\u00e1lna \u010diara",
"Horizontal space": "Horizont\u00e1lny priestor",
"Insert\/edit image": "Vlo\u017ei\u0165\/upravi\u0165 obr\u00e1zok",
"General": "Hlavn\u00e9",
"Advanced": "Pokro\u010dil\u00e9",
"Source": "Zdroj",
"Border": "Or\u00e1movanie",
"Constrain proportions": "Vymedzen\u00e9 proporcie",
"Vertical space": "Vertik\u00e1lny priestor",
"Image description": "Popis obr\u00e1zku",
"Style": "\u0160t\u00fdl",
"Dimensions": "Rozmery",
"Insert date\/time": "Vlo\u017ei\u0165 d\u00e1tum\/\u010das",
"Url": "Url",
"Text to display": "Zobrazen\u00fd text",
"Insert link": "Vlo\u017ei\u0165 odkaz",
"New window": "Nov\u00e9 okno",
"None": "\u017diadne",
"Target": "Cie\u013e",
"Insert\/edit link": "Vlo\u017ei\u0165\/upravi\u0165 odkaz",
"Insert\/edit video": "Vlo\u017ei\u0165\/upravi\u0165 video",
"Poster": "Uk\u00e1\u017eka",
"Alternative source": "Alternat\u00edvny zdroj",
"Paste your embed code below:": "Vlo\u017ete k\u00f3d pre vlo\u017eenie na str\u00e1nku:",
"Insert video": "Vlo\u017ei\u0165 video",
"Embed": "Vlo\u017een\u00e9",
"Nonbreaking space": "Nedelite\u013en\u00e1 medzera",
"Page break": "Zalomenie str\u00e1nky",
"Preview": "N\u00e1h\u013ead",
"Print": "Tla\u010di\u0165",
"Save": "Ulo\u017ei\u0165",
"Could not find the specified string.": "Zadan\u00fd re\u0165azec sa nena\u0161iel.",
"Replace": "Nahradi\u0165",
"Next": "Nasleduj\u00face",
"Whole words": "Cel\u00e9 slov\u00e1",
"Find and replace": "Vyh\u013eada\u0165 a nahradi\u0165",
"Replace with": "Nahradi\u0165 za",
"Find": "H\u013eada\u0165",
"Replace all": "Nahradi\u0165 v\u0161etko",
"Match case": "Rozli\u0161ova\u0165 ve\u013ek\u00e9\/mal\u00e9",
"Prev": "Predch\u00e1dzaj\u00face",
"Spellcheck": "Kontrola pravopisu",
"Finish": "Dokon\u010di\u0165",
"Ignore all": "Ignorova\u0165 v\u0161etko",
"Ignore": "Ignorova\u0165",
"Insert row before": "Vlo\u017ei\u0165 nov\u00fd riadok pred",
"Rows": "Riadky",
"Height": "V\u00fd\u0161ka",
"Paste row after": "Vlo\u017ei\u0165 riadok za",
"Alignment": "Zarovnanie",
"Column group": "Skupina st\u013apcov",
"Row": "Riadok",
"Insert column before": "Prida\u0165 nov\u00fd st\u013apec pred",
"Split cell": "Rozdeli\u0165 bunku",
"Cell padding": "Odsadenie v bunk\u00e1ch",
"Cell spacing": "Priestor medzi bunkami",
"Row type": "Typ riadku",
"Insert table": "Vlo\u017ei\u0165 tabu\u013eku",
"Body": "Telo",
"Caption": "Popisok",
"Footer": "P\u00e4ti\u010dka",
"Delete row": "Zmaza\u0165 riadok",
"Paste row before": "Vlo\u017ei\u0165 riadok pred",
"Scope": "Oblas\u0165",
"Delete table": "Zmaza\u0165 tabu\u013eku",
"Header cell": "Bunka hlavi\u010dky",
"Column": "St\u013apec",
"Cell": "Bunka",
"Header": "Z\u00e1hlavie",
"Cell type": "Typ bunky",
"Copy row": "Kop\u00edrova\u0165 riadok",
"Row properties": "Vlastnosti riadku",
"Table properties": "Nastavenia tabu\u013eky",
"Row group": "Skupina riadkov",
"Right": "Vpravo",
"Insert column after": "Prida\u0165 nov\u00fd st\u013apec za",
"Cols": "St\u013apce",
"Insert row after": "Vlo\u017ei\u0165 nov\u00fd riadok za",
"Width": "\u0160\u00edrka",
"Cell properties": "Vlastnosti bunky",
"Left": "V\u013eavo",
"Cut row": "Vystrihn\u00fa\u0165 riadok",
"Delete column": "Vymaza\u0165 st\u013apec",
"Center": "Na stred",
"Merge cells": "Spoji\u0165 bunky",
"Insert template": "Vlo\u017ei\u0165 \u0161abl\u00f3nu",
"Templates": "\u0160abl\u00f3ny",
"Background color": "Farba pozadia",
"Text color": "Farba textu",
"Show blocks": "Zobrazi\u0165 bloky",
"Show invisible characters": "Zobrazi\u0165 skryt\u00e9 znaky",
"Words: {0}": "Slov: {0}",
"Insert": "Vlo\u017ei\u0165",
"File": "S\u00fabor",
"Edit": "Upravi\u0165",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Textov\u00e9 pole. Stla\u010dte ALT-F9 pre zobrazenie menu, ALT-F10 pre zobrazenie panela n\u00e1strojov, ALT-0 pre n\u00e1povedu.",
"Tools": "N\u00e1stroje",
"View": "Zobrazi\u0165",
"Table": "Tabu\u013eka",
"Format": "Form\u00e1t"
});

==> Joomla_3.9.8_in_Japanese.zip: Joomla_3.9.8_in_Japanese/media/editors/tinymce/langs/sk.js <==
tinymce.addI18n('sk',{
"Cut": "Vystrihn\u00fa\u0165",
"Heading 5": "Nadpis 5",
"Header 2": "Nadpis 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "V\u00e1\u0161 prehliada\u010d nepodporuje priamy pr\u00edstup do schr\u00e1nky. Pou\u017eite kl\u00e1vesov\u00e9 skratky Ctrl+X\/C\/V.",
"Heading 4": "Nadpis 4",
"Div": "Blok",
"Heading 2": "Nadpis 2",
"Paste": "Vlo\u017ei\u0165",
"Close": "Zatvori\u0165",
"Font Family": "P\u00edsmo",
"Pre": "Preform\u00e1tovan\u00fd",
"Align right": "Zarovna\u0165 vpravo",
"New document": "Nov\u00fd dokument",
"Blockquote": "Cit\u00e1cia",
"Numbered list": "\u010c\u00edslovan\u00fd zoznam",
"Heading 1": "Nadpis 1",
"Headings": "Nadpisy",
"Increase indent": "Zv\u00e4\u010d\u0161i\u0165 odsadenie",
"Formats": "Form\u00e1ty",
"Headers": "Nadpisy",
"Select all": "Ozna\u010di\u0165 v\u0161etko",
"Header 3": "Nadpis 3",
"Blocks": "Bloky",
"Undo": "Vr\u00e1ti\u0165",
"Strikethrough": "Pre\u010diarknut\u00e9",
"Bullet list": "Odr\u00e1\u017eky",
"Header 1": "Nadpis 1",
"Superscript": "Horn\u00fd index",
"Clear formatting": "Vymaza\u0165 form\u00e1tovanie",
"Font Sizes": "Ve\u013ekos\u0165 p\u00edsma",
"Subscript": "Spodn\u00fd index",
"Header 6": "Nadpis 6",
"Redo": "Znova",
"Paragraph": "Odsek",
"Ok": "Ok",
"Bold": "Tu\u010dn\u00e9",
"Code": "K\u00f3d",
"Italic": "Kurz\u00edva",
"Align center": "Zarovna\u0165 na stred",
"Header 5": "Nadpis 5",
"Heading 6": "Nadpis 6",
"Heading 3": "Nadpis 3",
"Decrease indent": "Zmen\u0161i\u0165 odsadenie",
"Header 4": "Nadpis 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Vkladanie je v m\u00f3de neform\u00e1tovan\u00e9ho textu. Vkladan\u00fd obsah bude vlo\u017een\u00fd ako neform\u00e1tovan\u00fd, a\u017e pok\u00fdm t\u00fato mo\u017enos\u0165 nevypnete.",
"Underline": "Pod\u010diarknut\u00e9",
"Cancel": "Zru\u0161i\u0165",
"Justify": "Zarovna\u0165",
"Inline": "\u0160t\u00fdly",
"Copy": "Kop\u00edrova\u0165",
"Align left": "Zarovna\u0165 v\u013eavo",
"Visual aids": "Vizu\u00e1lne pom\u00f4cky",
"Lower Greek": "Mal\u00e9 gr\u00e9cke p\u00edsmen\u00e1",
"Square": "\u0160tvorec",
"Default": "V\u00fdchodzie",
"Lower Alpha": "Mal\u00e9 p\u00edsmen\u00e1",
"Circle": "Kruh",
"Disc": "Disk",
"Upper Alpha": "Ve\u013ek\u00e9 p\u00edsmen\u00e1",
"Upper Roman": "Ve\u013ek\u00e9 r\u00edmske \u010d\u00edslice",
"Lower Roman": "Mal\u00e9 r\u00edmske \u010d\u00edslice",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "Id by malo za\u010d\u00edna\u0165 p\u00edsmenom, nasledovan\u00e9 p\u00edsmenami, \u010d\u00edslami, pom\u013a\u010dkami, bodkami, dvojbodkami alebo podtr\u017en\u00edkmi.",
"Name": "N\u00e1zov",
"Anchor": "Odkaz",
"Id": "Id",
"You have unsaved changes are you sure you want to navigate away?": "M\u00e1te neulo\u017een\u00e9 zmeny, naozaj chcete opusti\u0165 str\u00e1nku?",
"Restore last draft": "Obnovi\u0165 posledn\u00fd koncept",
"Special character": "\u0160peci\u00e1lny znak",
"Source code": "Zdrojov\u00fd k\u00f3d",
"Language": "Jazyk",
"Insert\/Edit code sample": "Vlo\u017ei\u0165\/upravi\u0165 vzorku k\u00f3du",
"B": "B",
"R": "R",
"G": "G",
"Color": "Farba",
"Right to left": "Sprava do\u013eava",
"Left to right": "Z\u013eava doprava",
"Emoticons": "Smajl\u00edci",
"Robots": "Preh\u013ead\u00e1vacie roboty",
"Document properties": "Vlastnosti dokumentu",
"Title": "Nadpis",
"Keywords": "K\u013e\u00fa\u010dov\u00e9 slov\u00e1",
"Encoding": "K\u00f3dovanie",
"Description": "Popis",
"Author": "Autor",
"Fullscreen": "Na cel\u00fa obrazovku",
"Horizontal line": "Horizont\u00e1lna \u010diara",
"Horizontal space": "Horizont\u00e1lny priestor",
"Insert\/edit image": "Vlo\u017ei\u0165\/upravi\u0165 obr\u00e1zok",
"General": "Hlavn\u00e9",
"Advanced": "Pokro\u010dil\u00e9",
"Source": "Zdroj",
"Border": "Or\u00e1movanie",
"Constrain proportions": "Vymedzen\u00e9 proporcie",
"Vertical space": "Vertik\u00e1lny priestor",
"Image description": "Popis obr\u00e1zku",
"Style": "\u0160t\u00fdl",
"Dimensions": "Rozmery",
"Insert image": "Vlo\u017ei\u0165 obr\u00e1zok",
"Image": "Obr\u00e1zok",
"Zoom in": "Pribl\u00ed\u017ei\u0165",
"Contrast": "Kontrast",
"Back": "Sp\u00e4\u0165",
"Gamma": "Gama",
"Flip horizontally": "Preklopi\u0165 horizont\u00e1lne",
"Resize": "Zmeni\u0165 ve\u013ekos\u0165",
"Sharpen": "Zaostri\u0165",
"Zoom out": "Oddiali\u0165",
"Image options": "Mo\u017enosti obr\u00e1zku",
"Apply": "Pou\u017ei\u0165",
"Brightness": "Jas",
"Rotate clockwise": "Oto\u010di\u0165 v smere hodinov\u00fdch ru\u010di\u010diek",
"Rotate counterclockwise": "Oto\u010di\u0165 proti smeru hodinov\u00fdch ru\u010di\u010diek",
"Edit image": "Upravi\u0165 obr\u00e1zok",
"Color levels": "\u00darovne farieb",
"Crop": "Vyreza\u0165",
"Orientation": "Orient\u00e1cia",
"Flip vertically": "Preklopi\u0165 vertik\u00e1lne",
"Invert": "Invertova\u0165",
"Date\/time": "D\u00e1tum\/\u010das",
"Insert date\/time": "Vlo\u017ei\u0165 d\u00e1tum\/\u010das",
"Remove link": "Odstr\u00e1ni\u0165 odkaz",
"Url": "Url",
"Text to display": "Zobrazen\u00fd text",
"Anchors": "Kotvy",
"Insert link": "Vlo\u017ei\u0165 odkaz",
"Link": "Odkaz",
"New window": "Nov\u00e9 okno",
"None": "\u017diadne",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "URL adresa ktor\u00fa ste zadali vyzer\u00e1 ako extern\u00fd odkaz. Chcete prida\u0165 vy\u017eadovan\u00fa http:\/\/ predponu?",
"Paste or type a link": "Prilepte alebo nap\u00ed\u0161te odkaz",
"Target": "Cie\u013e",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "URL, ktor\u00fa ste vlo\u017eili je pravdepodobne emailov\u00e1 adresa. \u017del\u00e1te si prida\u0165 vy\u017eadovan\u00fa mailto: predponu?",
"Insert\/edit link": "Vlo\u017ei\u0165\/upravi\u0165 odkaz",
"Insert\/edit video": "Vlo\u017ei\u0165\/upravi\u0165 video",
"Media": "M\u00e9di\u00e1",
"Alternative source": "Alternat\u00edvny zdroj",
"Paste your embed code below:": "Vlo\u017ete k\u00f3d pre vlo\u017eenie na str\u00e1nku:",
"Insert video": "Vlo\u017ei\u0165 video",
"Poster": "Uk\u00e1\u017eka",
"Insert\/edit media": "Vlo\u017ei\u0165\/upravi\u0165 m\u00e9di\u00e1",
"Embed": "Vlo\u017een\u00e9",
"Nonbreaking space": "Nedelite\u013en\u00e1 medzera",
"Page break": "Zalomenie str\u00e1nky",
"Paste as text": "Vlo\u017ei\u0165 ako text",
"Preview": "N\u00e1h\u013ead",
"Print": "Tla\u010di\u0165",
"Save": "Ulo\u017ei\u0165",
"Could not find the specified string.": "Zadan\u00fd re\u0165azec sa nena\u0161iel.",
"Replace": "Nahradi\u0165",
"Next": "Nasleduj\u00face",
"Whole words": "Cel\u00e9 slov\u00e1",
"Find and replace": "Vyh\u013eada\u0165 a nahradi\u0165",
"Replace with": "Nahradi\u0165 za",
"Find": "H\u013eada\u0165",
"Replace all": "Nahradi\u0165 v\u0161etko",
"Match case": "Rozli\u0161ova\u0165 ve\u013ek\u00e9\/mal\u00e9",
"Prev": "Predch\u00e1dzaj\u00face",
"Spellcheck": "Kontrola pravopisu",
"Finish": "Dokon\u010di\u0165",
"Ignore all": "Ignorova\u0165 v\u0161etko",
"Ignore": "Ignorova\u0165",
"Add to Dictionary": "Prida\u0165 do slovn\u00edka",
"Insert row before": "Vlo\u017ei\u0165 nov\u00fd riadok pred",
"Rows": "Riadky",
"Height": "V\u00fd\u0161ka",
"Paste row after": "Vlo\u017ei\u0165 riadok za",
"Alignment": "Zarovnanie",
"Border color": "Farba or\u00e1movania",
"Column group": "Skupina st\u013apcov",
"Row": "Riadok",
"Insert column before": "Prida\u0165 nov\u00fd st\u013apec pred",
"Split cell": "Rozdeli\u0165 bunku",
"Cell padding": "Odsadenie v bunk\u00e1ch",
"Cell spacing": "Priestor medzi bunkami",
"Row type": "Typ riadku",
"Insert table": "Vlo\u017ei\u0165 tabu\u013eku",
"Body": "Telo",
"Caption": "Popisok",
"Footer": "P\u00e4ti\u010dka",
"Delete row": "Zmaza\u0165 riadok",
"Paste row before": "Vlo\u017ei\u0165 riadok pred",
"Scope": "Oblas\u0165",
"Delete table": "Zmaza\u0165 tabu\u013eku",
"H Align": "Horizont\u00e1lne zarovnanie",
"Top": "Vrch",
"Header cell": "Bunka z\u00e1hlavia",
"Column": "St\u013apec",
"Row group": "Skupina riadkov",
"Cell": "Bunka",
"Middle": "Stred",
"Cell type": "Typ bunky",
"Copy row": "Kop\u00edrova\u0165 riadok",
"Row properties": "Vlastnosti riadku",
"Table properties": "Nastavenia tabu\u013eky",
"Bottom": "Spodok",
"V Align": "Vertik\u00e1lne zarovnanie",
"Header": "Z\u00e1hlavie",
"Right": "Vpravo",
"Insert column after": "Prida\u0165 nov\u00fd st\u013apec za",
"Cols": "St\u013apce",
"Insert row after": "Vlo\u017ei\u0165 nov\u00fd riadok za",
"Width": "\u0160\u00edrka",
"Cell properties": "Vlastnosti bunky",
"Left": "V\u013eavo",
"Cut row": "Vystrihn\u00fa\u0165 riadok",
"Delete column": "Vymaza\u0165 st\u013apec",
"Center": "Na stred",
"Merge cells": "Spoji\u0165 bunky",
"Insert template": "Vlo\u017ei\u0165 \u0161abl\u00f3nu",
"Templates": "\u0160abl\u00f3ny",
"Background color": "Farba pozadia",
"Custom...": "Vlastn\u00e1...",
"Custom color": "Vlastn\u00e1 farba",
"No color": "Bez farby",
"Text color": "Farba textu",
"Table of Contents": "Obsah",
"Show blocks": "Zobrazi\u0165 bloky",
"Show invisible characters": "Zobrazi\u0165 skryt\u00e9 znaky",
"Words: {0}": "Slov: {0}",
"Insert": "Vlo\u017ei\u0165",
"File": "S\u00fabor",
"Edit": "Upravi\u0165",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Textov\u00e9 pole. Stla\u010dte ALT-F9 pre zobrazenie menu, ALT-F10 pre zobrazenie panela n\u00e1strojov, ALT-0 pre n\u00e1povedu.",
"Tools": "N\u00e1stroje",
"View": "Zobrazi\u0165",
"Table": "Tabu\u013eka",
"Format": "Form\u00e1t"
});
